@@ -20,8 +20,9 @@ fi
 # an old version of configure, which issues compiler warnings and
 # errors out. This may be removed with upgraded configure.in file.
 makecmd="make"
-if [[ "$#" -eq 2 ]]; then
-    makecmd="make CFLAGS='$CFLAGS $2' CXXFLAGS='$CXXFLAGS $2'"
+if [[ "$#" -ge 2 ]]; then
+    ARGS=("$@")
+    makecmd="make CFLAGS='$CFLAGS ${ARGS[@]:1}' CXXFLAGS='$CXXFLAGS ${ARGS[@]:1}'"
 fi
 
 # non-existent variables as an errors
@@ -37,6 +38,7 @@ export INSTALL_PREFIX=$1
     --with-bzlib \
     --with-blas \
     --with-lapack \
+    --with-libsvm \
     --with-readline \
     --with-openmp \
     --with-pdal \
