@@ -1,7 +1,6 @@
-
 /*****************************************************************************
-* just a test for debugging purpose, imitating dbf driver -a.sh.
-*****************************************************************************/
+ * just a test for debugging purpose, imitating dbf driver -a.sh.
+ *****************************************************************************/
 
 #include <stdlib.h>
 #include <grass/dbmi.h>
@@ -21,14 +20,14 @@ int main(int argc, char *argv[])
 
     driver = db_start_driver("dbf");
     if (driver == NULL)
-	exit(EXIT_FAILURE);
+        exit(EXIT_FAILURE);
 
     db_init_handle(&handle);
     db_set_handle(&handle, "dbf_catalog", NULL);
 
     if (db__test_database_open()) {
-	db_error("Multiple open databases not allowed");
-	return DB_OK;
+        db_error("Multiple open databases not allowed");
+        return DB_OK;
     }
 
     /* call the procedure */
@@ -36,29 +35,30 @@ int main(int argc, char *argv[])
 
     /* send the return code */
     if (stat != DB_OK) {
-	db_free_handle(&handle);
-	return DB_OK;
+        db_free_handle(&handle);
+        return DB_OK;
     }
 
     /* record the open in the driver state */
     db__mark_database_open(db_get_handle_dbname(&handle),
-			   db_get_handle_dbpath(&handle));
+                           db_get_handle_dbpath(&handle));
     /* DO NOT free the handle since we saved the pointers to the name,path */
 
-    select = (dbString *) G_malloc(1024);
+    select = (dbString *)G_malloc(1024);
 
     db_init_string(select);
 
     db_set_string(select,
-		  "select id, quality, flow from river where (flow = 10) or (flow = 20) or (flow = 30) or (flow = 5) or (flow = 7)");
+                  "select id, quality, flow from river where (flow = 10) or "
+                  "(flow = 20) or (flow = 30) or (flow = 5) or (flow = 7)");
 
     /* create a cursor */
-    cursor = (dbCursor *) db_malloc(sizeof(dbCursor));
+    cursor = (dbCursor *)db_malloc(sizeof(dbCursor));
     if (cursor == NULL)
-	return db_get_error_code();
-    token = db_new_token((dbAddress) cursor);
+        return db_get_error_code();
+    token = db_new_token((dbAddress)cursor);
     if (token < 0)
-	return db_get_error_code();
+        return db_get_error_code();
     db_init_cursor(cursor);
     cursor->driver = driver;
 
@@ -78,9 +78,9 @@ int main(int argc, char *argv[])
 
     /* see if a database is open */
     if (!db__test_database_open()) {
-	db_error("no database is open");
-	G_debug(3, "db_d_close_database(): would sent DB_FAILURE");
-	return DB_OK;
+        db_error("no database is open");
+        G_debug(3, "db_d_close_database(): would sent DB_FAILURE");
+        return DB_OK;
     };
     /* make sure all cursors are closed */
     db__close_all_cursors();
@@ -91,8 +91,8 @@ int main(int argc, char *argv[])
 
     /* send the return code */
     if (stat != DB_OK) {
-	G_debug(3, "db_d_close_database(): would sent DB_FAILURE");
-	return DB_OK;
+        G_debug(3, "db_d_close_database(): would sent DB_FAILURE");
+        return DB_OK;
     }
     G_debug(3, "db_d_close_database(): would sent DB_OK");
 
@@ -100,8 +100,6 @@ int main(int argc, char *argv[])
     db__mark_database_closed();
     db__init_driver_state();
 
-
     G_debug(3, "main(): ok");
     return DB_OK;
-
 }
