@@ -16,7 +16,7 @@
 #include "globals.h"
 #include "proto.h"
 
-int db__driver_init(int argc, char *argv[])
+int db__driver_init(int argc UNUSED, char *argv[] UNUSED)
 {
     init_error();
     return DB_OK;
