@@ -1,4 +1,3 @@
-
 /**
  * \file index.c
  *
@@ -18,7 +17,6 @@
 #include "globals.h"
 #include "proto.h"
 
-
 /**
  * \fn int db__driver_create_index (dbIndex *index)
  *
@@ -28,7 +26,7 @@
  * \return int DB_FAILED on error; DB_OK on success
  */
 
-int db__driver_create_index(dbIndex * index)
+int db__driver_create_index(dbIndex *index)
 {
     int i, ncols;
     sqlite3_stmt *statement;
@@ -44,7 +42,7 @@ int db__driver_create_index(dbIndex * index)
 
     db_set_string(&sql, "create");
     if (db_test_index_type_unique(index))
-	db_append_string(&sql, " unique");
+        db_append_string(&sql, " unique");
 
     db_append_string(&sql, " index ");
     db_append_string(&sql, "if not exists ");
@@ -56,10 +54,10 @@ int db__driver_create_index(dbIndex * index)
     db_append_string(&sql, " ( ");
 
     for (i = 0; i < ncols; i++) {
-	if (i > 0)
-	    db_append_string(&sql, ", ");
+        if (i > 0)
+            db_append_string(&sql, ", ");
 
-	db_append_string(&sql, db_get_index_column_name(index, i));
+        db_append_string(&sql, db_get_index_column_name(index, i));
     }
 
     db_append_string(&sql, " )");
@@ -70,38 +68,37 @@ int db__driver_create_index(dbIndex * index)
      * If the database schema has changed, sqlite can prepare a statement,
      * but sqlite can not step, the statement needs to be prepared anew again */
     while (1) {
-	ret = sqlite3_prepare(sqlite, db_get_string(&sql), -1, &statement, &rest);
+        ret =
+            sqlite3_prepare(sqlite, db_get_string(&sql), -1, &statement, &rest);
 
-	if (ret != SQLITE_OK) {
-	    db_d_append_error("%s\n%s\n%s",
-			      _("Unable to create index:"),
-			      db_get_string(&sql),
-			      (char *)sqlite3_errmsg(sqlite));
-	    db_d_report_error();
-	    sqlite3_finalize(statement);
-	    db_free_string(&sql);
-	    return DB_FAILED;
-	}
+        if (ret != SQLITE_OK) {
+            db_d_append_error("%s\n%s\n%s", _("Unable to create index:"),
+                              db_get_string(&sql),
+                              (char *)sqlite3_errmsg(sqlite));
+            db_d_report_error();
+            sqlite3_finalize(statement);
+            db_free_string(&sql);
+            return DB_FAILED;
+        }
 
-	ret = sqlite3_step(statement);
-	/* get real result code */
-	ret = sqlite3_reset(statement);
+        ret = sqlite3_step(statement);
+        /* get real result code */
+        ret = sqlite3_reset(statement);
 
-	if (ret == SQLITE_SCHEMA) {
-	    sqlite3_finalize(statement);
-	    /* try again */
-	}
-	else if (ret != SQLITE_OK) {
-	    db_d_append_error("%s\n%s",
-			      _("Error in sqlite3_step():"),
-			      (char *)sqlite3_errmsg(sqlite));
-	    db_d_report_error();
-	    sqlite3_finalize(statement);
-	    db_free_string(&sql);
-	    return DB_FAILED;
-	}
-	else
-	    break;
+        if (ret == SQLITE_SCHEMA) {
+            sqlite3_finalize(statement);
+            /* try again */
+        }
+        else if (ret != SQLITE_OK) {
+            db_d_append_error("%s\n%s", _("Error in sqlite3_step():"),
+                              (char *)sqlite3_errmsg(sqlite));
+            db_d_report_error();
+            sqlite3_finalize(statement);
+            db_free_string(&sql);
+            return DB_FAILED;
+        }
+        else
+            break;
     }
 
     sqlite3_finalize(statement);
