@@ -1,15 +1,17 @@
-
 /****************************************************************************
  *
  * MODULE:       d.linegraph
- * AUTHOR(S):    Chris Rewerts, Agricultural Engineering, Purdue University (original contributor)
+ * AUTHOR(S):    Chris Rewerts, Agricultural Engineering,
+ *                   Purdue University (original contributor)
  *               Markus Neteler <neteler itc.it>
- *               Roberto Flor <flor itc.it>, Bernhard Reiter <bernhard intevation.de>, 
- *               Huidae Cho <grass4u gmail.com>, Glynn Clements <glynn gclements.plus.com>, 
+ *               Roberto Flor <flor itc.it>,
+ *               Bernhard Reiter <bernhard intevation.de>,
+ *               Huidae Cho <grass4u gmail.com>,
+ *               Glynn Clements <glynn gclements.plus.com>,
  *               Hamish Bowman <hamish_b yahoo.com>
  *               Vaclav Petras <wenzeslaus gmail com> (various features)
  *
- * PURPOSE:      
+ * PURPOSE:
  * COPYRIGHT:    (C) 1999-2016 by the GRASS Development Team
  *
  *               This program is free software under the GNU General Public
@@ -23,13 +25,13 @@
    February 1992
    program: d.linegraph
 
-   This program is based on Raghaven Srinivasan's modification  
-   of the programs written by Dave Johnson for d.histogram. 
+   This program is based on Raghaven Srinivasan's modification
+   of the programs written by Dave Johnson for d.histogram.
 
    Will read files containing a column of numbers and create line
-   graphs. One file can be used for the X axis, up to 10 for the 
+   graphs. One file can be used for the X axis, up to 10 for the
    Y axis. Each numerical x,y file should be a single column of
-   numbers.    
+   numbers.
  */
 
 #include <stdlib.h>
@@ -42,11 +44,8 @@
 #include "linegraph.h"
 
 /* the default order of precedence of colors to use for Y lines */
-int default_y_colors[] = {
-    0,
-    RED, GREEN, VIOLET, BLUE, ORANGE,
-    GRAY, BROWN, MAGENTA, WHITE, INDIGO
-};
+int default_y_colors[] = {0,    RED,   GREEN,   VIOLET, BLUE,  ORANGE,
+                          GRAY, BROWN, MAGENTA, WHITE,  INDIGO};
 
 static double rem(long int x, long int y)
 {
@@ -130,7 +129,7 @@ static char *icon_files(void)
     qsort(list, count, sizeof(char *), cmp);
 
     if (len > 0) {
-        ret = G_malloc((len + 1) * sizeof(char));       /* \0 */
+        ret = G_malloc((len + 1) * sizeof(char)); /* \0 */
         *ret = '\0';
         for (i = 0; i < count; i++) {
             if (i > 0)
@@ -149,8 +148,8 @@ static char *icon_files(void)
 
 int main(int argc, char **argv)
 {
-    double xoffset;             /* offset for x-axis */
-    double yoffset;             /* offset for y-axis */
+    double xoffset; /* offset for x-axis */
+    double yoffset; /* offset for y-axis */
     double text_height;
     double text_width;
     int i;
@@ -170,18 +169,17 @@ int main(int argc, char **argv)
     double y_line[3];
     int err;
 
-    struct in_file
-    {
-        int num_pnts;           /* number of lines in file  */
-        int color;              /* color to use for y lines */
+    struct in_file {
+        int num_pnts; /* number of lines in file  */
+        int color;    /* color to use for y lines */
         int r, g, b;
         double width;
-        float max;              /* maximum value in file    */
-        float min;              /* minimum value in file    */
-        float value;            /* current value read in    */
-        char name[1024];        /* name of file      */
-        char full_name[1024];   /* path/name of file    */
-        FILE *fp;               /* pointer to file        */
+        float max;            /* maximum value in file    */
+        float min;            /* minimum value in file    */
+        float value;          /* current value read in    */
+        char name[1024];      /* name of file      */
+        char full_name[1024]; /* path/name of file    */
+        FILE *fp;             /* pointer to file        */
     };
 
     struct in_file in[12];
@@ -198,8 +196,6 @@ int main(int argc, char **argv)
     char *name, *xlabel;
     char color_name[20];
 
-    FILE *fopen();
-
     struct Option *dir_opt, *x_opt, *y_opt;
     struct Option *y_color_opt;
     struct Option *color_table_opt;
@@ -223,8 +219,8 @@ int main(int argc, char **argv)
     module = G_define_module();
     G_add_keyword(_("display"));
     G_add_keyword(_("cartography"));
-    module->description =
-        _("Generates and displays simple line graphs in the active graphics monitor display frame.");
+    module->description = _("Generates and displays simple line graphs in the "
+                            "active graphics monitor display frame.");
 
     x_opt = G_define_option();
     x_opt->key = "x_file";
@@ -301,7 +297,7 @@ int main(int argc, char **argv)
     y_range_opt = G_define_option();
     y_range_opt->key = "y_range";
     y_range_opt->description =
-        _("Minimum and maximun value for Y axis (min,max)");
+        _("Minimum and maximum value for Y axis (min,max)");
     y_range_opt->type = TYPE_DOUBLE;
     y_range_opt->key_desc = "min,max";
     y_range_opt->required = NO;
@@ -340,7 +336,8 @@ int main(int argc, char **argv)
     point_symbol_opt->required = NO;
     point_symbol_opt->multiple = NO;
     point_symbol_opt->answer = "basic/circle";
-    /* This could also use ->gisprompt = "old,symbol,symbol" instead of ->options */
+    /* This could also use ->gisprompt = "old,symbol,symbol" instead of
+     * ->options */
     point_symbol_opt->options = icon_files();
     point_symbol_opt->description = _("Symbol for point");
     point_symbol_opt->guisection = _("Points");
@@ -387,7 +384,7 @@ int main(int argc, char **argv)
 
     /* TODO: put this to variables, and avoid -Wsign-compare */
     for (i = 0; i < 3; i++) {
-        for (j = 0; j < strlen(title[i]->answer); j++)
+        for (j = 0; (size_t)j < strlen(title[i]->answer); j++)
             if (title[i]->answer[j] == '_')
                 title[i]->answer[j] = ' ';
     }
@@ -422,8 +419,7 @@ int main(int argc, char **argv)
         sprintf(in[j].name, "%s", name);
 
         if ((in[j].fp = fopen(in[j].full_name, "r")) == NULL)
-            G_fatal_error(_("Unable to open input file <%s>"),
-                          in[j].full_name);
+            G_fatal_error(_("Unable to open input file <%s>"), in[j].full_name);
 
         num_y_files++;
         if (num_y_files > 10)
@@ -491,19 +487,17 @@ int main(int argc, char **argv)
     RGBA_Color secondary_color;
 
     if (draw_points) {
-        S_stroke(point_symbol, symbol_size, symbol_rotation,
-                 symbol_tolerance);
+        S_stroke(point_symbol, symbol_size, symbol_rotation, symbol_tolerance);
         primary_color.a = RGBA_COLOR_OPAQUE;
 
         if (point_color2_opt->answer) {
             int rgb_r, rgb_g, rgb_b;
-            int ret =
-                G_str_to_color(point_color2_opt->answer, &rgb_r, &rgb_g,
-                               &rgb_b);
+            int ret = G_str_to_color(point_color2_opt->answer, &rgb_r, &rgb_g,
+                                     &rgb_b);
+
             if (ret == 0)
                 G_fatal_error(_("Color <%s> cannot for option %s be parsed"),
-                              point_color2_opt->answer,
-                              point_color2_opt->key);
+                              point_color2_opt->answer, point_color2_opt->key);
             else if (ret == 2)
                 secondary_color.a = RGBA_COLOR_TRANSPARENT;
             else
@@ -511,7 +505,6 @@ int main(int argc, char **argv)
             secondary_color.r = rgb_r;
             secondary_color.g = rgb_g;
             secondary_color.b = rgb_b;
-
         }
     }
 
@@ -524,9 +517,9 @@ int main(int argc, char **argv)
     c = 0;
     j = 1;
     if (y_color_opt->answer != NULL) {
-        for (i = 0; i <= (strlen(y_color_opt->answer)); i++) {
+        for (i = 0; (size_t)i <= (strlen(y_color_opt->answer)); i++) {
             if ((y_color_opt->answer[i] == ',') ||
-                (i == (strlen(y_color_opt->answer)))) {
+                ((size_t)i == (strlen(y_color_opt->answer)))) {
                 color_name[c] = '\0';
                 in[j].color = D_translate_color(color_name);
                 j++;
@@ -539,8 +532,8 @@ int main(int argc, char **argv)
         /* in theory we could repeat the colors but that may seem random */
         /* TODO: repeat the colors if only one provided (as with width) */
         if (j - 1 < num_y_files)
-            G_fatal_error(_("Only <%d> colors given for <%d> lines"),
-                          j - 1, num_y_files);
+            G_fatal_error(_("Only <%d> colors given for <%d> lines"), j - 1,
+                          num_y_files);
     }
     else if (color_table_opt->answer) {
         struct Colors colors;
@@ -571,7 +564,7 @@ int main(int argc, char **argv)
         G_free(set);
     }
     else
-        /* no colors given on command line, use default list */
+    /* no colors given on command line, use default list */
     {
         for (i = 1; i <= num_y_files; i++) {
             in[i].color = default_y_colors[i];
@@ -581,11 +574,12 @@ int main(int argc, char **argv)
     if (line_width_opt->answer) {
         i = 0;
         while (line_width_opt->answers[i]) {
-            /* we could relax this and just stop/warn reading as with the colors */
+            /* we could relax this and just stop/warn reading as with the colors
+             */
             if (i + 1 > num_y_files)
                 G_fatal_error(_("Number of widths (%d) is higher then"
-                                " the number of files (%d)"), i + 1,
-                              num_y_files);
+                                " the number of files (%d)"),
+                              i + 1, num_y_files);
             /* TODO: remove indexing from 1 in the whole file */
             in[i + 1].width = atof(line_width_opt->answers[i]);
             i++;
@@ -597,7 +591,8 @@ int main(int argc, char **argv)
         }
         else if (num_y_files != i)
             G_fatal_error(_("Number of widths (%d) is lower then"
-                            " the number of files (%d)"), i, num_y_files);
+                            " the number of files (%d)"),
+                          i, num_y_files);
     }
 
     /* get coordinates of current screen window, in pixels */
@@ -642,18 +637,20 @@ int main(int argc, char **argv)
             in[i].num_pnts++;
             in[i].max = MAX(in[i].max, in[i].value);
             in[i].min = MIN(in[i].min, in[i].value);
-            if (i > 0) {        /* if we have a y file */
+            if (i > 0) { /* if we have a y file */
                 min_y = MIN(min_y, in[i].value);
                 max_y = MAX(max_y, in[i].value);
             }
         }
         if ((i > 0) && (in[0].num_pnts != in[i].num_pnts)) {
             if (in[i].num_pnts < in[0].num_pnts) {
-                G_warning(_("Y input file <%s> contains fewer data points than the X input file"),
+                G_warning(_("Y input file <%s> contains fewer data points than "
+                            "the X input file"),
                           in[i].name);
             }
             else {
-                G_warning(_("Y input file <%s> contains more data points than the X input file"),
+                G_warning(_("Y input file <%s> contains more data points than "
+                            "the X input file"),
                           in[i].name);
             }
 
@@ -713,19 +710,19 @@ int main(int argc, char **argv)
 
     if (tic_unit != 1 && scale_x_labels)
         G_fatal_error(_("Scale X labels cannot be used with this range"
-                        " of data (%f, %f)"), in[0].min, in[0].max);
+                        " of data (%f, %f)"),
+                      in[0].min, in[0].max);
 
     /* open all the data files again */
 
     for (i = 0; i <= num_y_files; i++) {
         if ((in[i].fp = fopen(in[i].full_name, "r")) == NULL) {
             D_close_driver();
-            G_fatal_error(_("Unable to open input file <%s>"),
-                          in[i].full_name);
+            G_fatal_error(_("Unable to open input file <%s>"), in[i].full_name);
         }
     }
 
-    /* loop through number of lines in x data file, 
+    /* loop through number of lines in x data file,
        then loop thru for each y file, drawing a piece of each line and a
        legend bar on each iteration evenly divisible, a tic-mark
        on those evenly divisible by tic_unit, and a tic_mark
@@ -754,12 +751,13 @@ int main(int argc, char **argv)
                     in[i].value *= y_scale;
                 if ((in[i].num_pnts >= line) && (err != 1)) {
                     D_close_driver();
-                    G_fatal_error(_("Problem reading <%s> data file at line %d"),
-                                  in[i].name, line);
+                    G_fatal_error(
+                        _("Problem reading <%s> data file at line %d"),
+                        in[i].name, line);
                 }
 
-                /* in case the Y file has fewer lines than the X file, we will skip
-                   trying to draw when we run out of data */
+                /* in case the Y file has fewer lines than the X file, we will
+                   skip trying to draw when we run out of data */
 
                 /* draw increment of each Y file's data */
 
@@ -774,12 +772,11 @@ int main(int argc, char **argv)
 
                 else {
                     if (in[i].value < 0)
-                        new_y[i] = (yoffset - yscale * (-1 *
-                                                        (min_y -
-                                                         in[i].value)));
+                        new_y[i] =
+                            (yoffset - yscale * (-1 * (min_y - in[i].value)));
                     else
-                        new_y[i] = (yoffset - yscale * (in[i].value +
-                                                        (min_y * -1)));
+                        new_y[i] =
+                            (yoffset - yscale * (in[i].value + (min_y * -1)));
                 }
 
                 new_x = xoffset + (line * xscale);
@@ -816,8 +813,8 @@ int main(int argc, char **argv)
                               &secondary_color);
                     /* last point */
                     if (line == in[i].num_pnts - 1)
-                        D_symbol2(point_symbol, new_x, new_y[i],
-                                  &primary_color, &secondary_color);
+                        D_symbol2(point_symbol, new_x, new_y[i], &primary_color,
+                                  &secondary_color);
                 }
                 prev_y[i] = new_y[i];
             }
@@ -889,7 +886,7 @@ int main(int argc, char **argv)
 
     /* draw the x-axis label */
     if ((strcmp(title[0]->answer, "") == 0) && (strcmp(tic_name, "") == 0))
-        xlabel =  G_store("");
+        xlabel = G_store("");
     else
         G_asprintf(&xlabel, "X: %s %s", title[0]->answer, tic_name);
     text_height = (b - t) * TEXT_HEIGHT;
@@ -962,7 +959,8 @@ int main(int argc, char **argv)
         }
         if (tic_unit != 1 && scale_y_labels)
             G_fatal_error(_("Scale Y labels cannot be used with this"
-                            " range of data (%f, %f)"), min_y, max_y);
+                            " range of data (%f, %f)"),
+                          min_y, max_y);
         /* Y-AXIS LOOP */
         for (i = (int)min_y; i <= (int)max_y; i += tic_unit) {
             if (rem(i, tic_every) == 0.0) {
