@@ -1,4 +1,3 @@
-
 /****************************************************************************
  *
  * MODULE:       g.access
@@ -6,8 +5,10 @@
  *               Markus Neteler <neteler itc.it>
  *               Bernhard Reiter <bernhard intevation.de>,
  *               Glynn Clements <glynn gclements.plus.com>,
- *               Hamish Bowman <hamish_b yahoo.com>, Radim Blazek <radim.blazek gmail.com>
- * PURPOSE:      Controls access to the current mapset for other users on the system
+ *               Hamish Bowman <hamish_b yahoo.com>,
+ *               Radim Blazek <radim.blazek gmail.com>
+ * PURPOSE:      Controls access to the current mapset for other users
+ *               on the system
  * COPYRIGHT:    (C) 1999-2006, 2011 by the GRASS Development Team
  *
  *               This program is free software under the GNU General Public
@@ -15,6 +16,7 @@
  *               for details.
  *
  *****************************************************************************/
+
 #include <stdlib.h>
 #include <string.h>
 #include <unistd.h>
@@ -25,8 +27,8 @@
 int main(int argc, char *argv[])
 {
     char path[GPATH_MAX];
-    int perms;			/* full mapset permissions */
-    int group, other;		/* bool. want group/other permission */
+    int perms;        /* full mapset permissions */
+    int group, other; /* bool. want group/other permission */
     struct Option *group_opt, *other_opt;
     struct GModule *module;
 
@@ -37,10 +39,10 @@ int main(int argc, char *argv[])
     G_add_keyword(_("general"));
     G_add_keyword(_("map management"));
     G_add_keyword(_("permission"));
-    module->label =
-	_("Controls access to the current mapset for other users on the system.");
+    module->label = _(
+        "Controls access to the current mapset for other users on the system.");
     module->description = _("If no option given, prints current status.");
-    
+
     group_opt = G_define_option();
     group_opt->key = "group";
     group_opt->type = TYPE_STRING;
@@ -56,12 +58,13 @@ int main(int argc, char *argv[])
     other_opt->options = "grant,revoke";
     other_opt->description = _("Access for others");
     other_opt->guisection = _("Settings");
-    
+
     if (G_parser(argc, argv))
-	exit(EXIT_FAILURE);
+        exit(EXIT_FAILURE);
 
 #ifdef __MINGW32__
-    G_fatal_error(_("UNIX filesystem access controls are not supported by MS-Windows"));
+    G_fatal_error(
+        _("UNIX filesystem access controls are not supported by MS-Windows"));
 #endif
 
     /* get the unix file name for the mapset directory */
@@ -69,23 +72,24 @@ int main(int argc, char *argv[])
 
     /* this part is until PERMANENT no longer holds DEFAULT_WIND and MYNAME */
     if (strcmp(G_mapset(), "PERMANENT") == 0)
-	G_fatal_error(_("Access to the PERMANENT mapset must be open, nothing changed"));
+        G_fatal_error(
+            _("Access to the PERMANENT mapset must be open, nothing changed"));
 
     /* get the current permissions */
     if (get_perms(path, &perms, &group, &other) < 0)
-	G_fatal_error(_("Unable to determine mapset permissions"));
+        G_fatal_error(_("Unable to determine mapset permissions"));
 
     if (group_opt->answer) {
-	if (group_opt->answer[0] == 'g')
-	    group = 1;
-	else
-	    group = 0;
+        if (group_opt->answer[0] == 'g')
+            group = 1;
+        else
+            group = 0;
     }
     if (other_opt->answer) {
-	if (other_opt->answer[0] == 'g')
-	    other = 1;
-	else
-	    other = 0;
+        if (other_opt->answer[0] == 'g')
+            other = 1;
+        else
+            other = 0;
     }
 
     set_perms(path, perms, group, other);
