@@ -13,19 +13,19 @@ void create_location(const char *location)
     ret = G_make_location_crs(location, &cellhd, projinfo, projunits, projsrid,
                               projwkt);
     if (ret == 0)
-        G_message(_("Location <%s> created"), location);
+        G_message(_("Project <%s> created"), location);
     else if (ret == -1)
-        G_fatal_error(_("Unable to create location <%s>: %s"), location,
+        G_fatal_error(_("Unable to create project <%s>: %s"), location,
                       strerror(errno));
     else if (ret == -2)
         G_fatal_error(_("Unable to create projection files: %s"),
                       strerror(errno));
     else
         /* Shouldn't happen */
-        G_fatal_error(_("Unable to create location <%s>"), location);
+        G_fatal_error(_("Unable to create project <%s>"), location);
 
-    G_message(_("You can switch to the new location by\n`%s=%s`"),
-              "g.mapset mapset=PERMANENT location", location);
+    G_message(_("You can switch to the new project by\n`%s=%s`"),
+              "g.mapset mapset=PERMANENT project", location);
 }
 
 void modify_projinfo(void)
@@ -36,7 +36,8 @@ void modify_projinfo(void)
     if (strcmp(mapset, "PERMANENT") != 0)
         G_fatal_error(
             _("You must select the PERMANENT mapset before updating the "
-              "current location's projection (current mapset is <%s>)"),
+              "current project's coordinate reference system"
+              " (current mapset is <%s>)"),
             mapset);
 
     /* Read projection information from current location first */
