@@ -17,10 +17,10 @@ This program is free software under the GNU General Public License
 
 @author Anna Petrasova <kratochanna gmail.com>
 """
+
 import os
 import wx
 import wx.aui
-import six
 
 import grass.script as gcore
 import grass.temporal as tgis
@@ -143,7 +143,7 @@ class AnimationFrame(wx.Frame):
             .DestroyOnClose(True)
             .Layer(0),
         )
-        for name, slider in six.iteritems(self.animationSliders):
+        for name, slider in self.animationSliders.items():
             self._mgr.AddPane(
                 slider,
                 wx.aui.AuiPaneInfo()
@@ -182,7 +182,7 @@ class AnimationFrame(wx.Frame):
             .Layer(2)
             .Row(1)
             .Position(0)
-            .BestSize((self.toolbars["mainToolbar"].GetBestSize())),
+            .BestSize(self.toolbars["mainToolbar"].GetBestSize()),
         )
 
         self.toolbars["animationToolbar"] = AnimationToolbar(self)
@@ -201,7 +201,7 @@ class AnimationFrame(wx.Frame):
             .Layer(2)
             .Row(1)
             .Position(1)
-            .BestSize((self.toolbars["animationToolbar"].GetBestSize())),
+            .BestSize(self.toolbars["animationToolbar"].GetBestSize()),
         )
         self.controller.SetAnimationToolbar(self.toolbars["animationToolbar"])
 
@@ -221,7 +221,7 @@ class AnimationFrame(wx.Frame):
             .Layer(2)
             .Row(1)
             .Position(2)
-            .BestSize((self.toolbars["miscToolbar"].GetBestSize())),
+            .BestSize(self.toolbars["miscToolbar"].GetBestSize()),
         )
 
     def SetAnimations(self, layerLists):
