@@ -19,8 +19,6 @@ This program is free software under the GNU General Public License
 @author Luca Delucchi <lucadeluge gmail.com> (language choice)
 """
 
-from __future__ import print_function
-
 import os
 import sys
 import copy
@@ -64,7 +62,7 @@ class SettingsJSONEncoder(json.JSONEncoder):
             else:
                 return item
 
-        return super(SettingsJSONEncoder, self).iterencode(color(obj))
+        return super().iterencode(color(obj))
 
 
 def settings_JSON_decode_hook(obj):
@@ -154,6 +152,10 @@ class Settings:
                 "region": {
                     "resAlign": {"enabled": False},
                 },
+                "singleWinPanesLayoutPos": {
+                    "enabled": False,
+                    "pos": "",
+                },
             },
             #
             # datacatalog
@@ -171,10 +173,7 @@ class Settings:
                 # ask when quitting wxGUI or closing display
                 "askOnQuit": {"enabled": True},
                 # hide tabs
-                "hideTabs": {
-                    "search": False,
-                    "pyshell": False,
-                },
+                "hideTabs": {"search": False, "pyshell": False, "history": False},
                 "copySelectedTextToClipboard": {"enabled": False},
             },
             #
@@ -185,6 +184,10 @@ class Settings:
                     "type": "Courier New",
                     "size": 10,
                 },
+                "manualPageFont": {
+                    "faceName": "",
+                    "pointSize": "",
+                },
                 # expand/collapse element list
                 "elementListExpand": {"selection": 0},
                 "menustyle": {"selection": 1},
@@ -734,6 +737,7 @@ class Settings:
                         "height": 100,
                     },
                 },
+                "grassAPI": {"selection": 0},  # script package
             },
             "mapswipe": {
                 "cursor": {
@@ -763,7 +767,7 @@ class Settings:
             },
         }
 
-        # quick fix, http://trac.osgeo.org/grass/ticket/1233
+        # quick fix, https://trac.osgeo.org/grass/ticket/1233
         # TODO
         if sys.platform == "darwin":
             self.defaultSettings["general"]["defWindowPos"]["enabled"] = False
@@ -876,6 +880,11 @@ class Settings:
             _("circle"),
         )
 
+        self.internalSettings["modeler"]["grassAPI"]["choices"] = (
+            _("Script package"),
+            _("PyGRASS"),
+        )
+
     def ReadSettingsFile(self, settings=None):
         """Reads settings file (mapset, location, gisdbase)"""
         if settings is None:
@@ -934,7 +943,7 @@ class Settings:
 
         try:
             fd = open(self.legacyFilePath, "r")
-        except IOError:
+        except OSError:
             sys.stderr.write(
                 _("Unable to read settings file <%s>\n") % self.legacyFilePath
             )
@@ -989,7 +998,7 @@ class Settings:
         try:
             with open(self.filePath, "w") as f:
                 json.dump(settings, f, indent=2, cls=SettingsJSONEncoder)
-        except IOError as e:
+        except OSError as e:
             raise GException(e)
         except Exception as e:
             raise GException(
