@@ -14,7 +14,6 @@ This program is free software under the GNU General Public License
 @author Anna Petrasova <kratochanna gmail.com>
 """
 
-
 import wx
 from gui_core.widgets import FloatValidator, IntegerValidator
 from core.giface import Notification
@@ -173,7 +172,7 @@ class CatalogReprojectionDialog(wx.Dialog):
             read=True,
             input=self.iLayer,
             dbase=self.iGisdbase,
-            location=self.iLocation,
+            project=self.iLocation,
             mapset=self.iMapset,
             env=self.oEnv,
         ).strip()
@@ -213,7 +212,7 @@ class CatalogReprojectionDialog(wx.Dialog):
         if self.etype == "raster":
             cmd.append("r.proj")
             cmd.append("dbase=" + self.iGisdbase)
-            cmd.append("location=" + self.iLocation)
+            cmd.append("project=" + self.iLocation)
             cmd.append("mapset=" + self.iMapset)
             cmd.append("input=" + self.iLayer)
             cmd.append("output=" + self.oLayer)
@@ -231,7 +230,7 @@ class CatalogReprojectionDialog(wx.Dialog):
         else:
             cmd.append("v.proj")
             cmd.append("dbase=" + self.iGisdbase)
-            cmd.append("location=" + self.iLocation)
+            cmd.append("project=" + self.iLocation)
             cmd.append("mapset=" + self.iMapset)
             cmd.append("input=" + self.iLayer)
             cmd.append("output=" + self.oLayer)
