@@ -18,32 +18,27 @@ for details.
 @author Anna Petrasova (kratochanna gmail com)
 @author Linda Kladivova (l.kladivova@seznam.cz)
 """
+
 import os
 import re
 import copy
-import time
 from multiprocessing import Process, Queue, cpu_count
 
-watchdog_used = True
-try:
-    from watchdog.observers import Observer
-    from watchdog.events import PatternMatchingEventHandler, FileSystemEventHandler
-except ImportError:
-    watchdog_used = False
-    PatternMatchingEventHandler = object
-    FileSystemEventHandler = object
-
-
 import wx
-from wx.lib.newevent import NewEvent
 
 from core.gcmd import RunCommand, GError, GMessage
 from core.utils import GetListOfLocations
 from core.debug import Debug
 from core.gthread import gThread
+from core.watchdog import (
+    EVT_UPDATE_MAPSET,
+    EVT_CURRENT_MAPSET_CHANGED,
+    MapsetWatchdog,
+    watchdog_used,
+)
 from gui_core.dialogs import TextEntryDialog
 from core.giface import StandaloneGrassInterface
-from core.treemodel import TreeModel, DictNode
+from core.treemodel import TreeModel, DictFilterNode
 from gui_core.treeview import TreeView
 from gui_core.wrap import Menu
 from datacatalog.dialogs import CatalogReprojectionDialog
@@ -81,10 +76,6 @@ from grass.grassdb.checks import (
 from grass.exceptions import CalledModuleError
 
 
-updateMapset, EVT_UPDATE_MAPSET = NewEvent()
-currentMapsetChanged, EVT_CURRENT_MAPSET_CHANGED = NewEvent()
-
-
 def getLocationTree(gisdbase, location, queue, mapsets=None, lazy=False):
     """Creates dictionary with mapsets, elements, layers for given location.
     Returns tuple with the dictionary and error (or None)"""
@@ -102,14 +93,14 @@ def getLocationTree(gisdbase, location, queue, mapsets=None, lazy=False):
         queue.put(
             (
                 maps_dict,
-                _("Failed to read mapsets from location <{l}>.").format(l=location),
+                _("Failed to read mapsets from project <{l}>.").format(l=location),
             )
         )
         gscript.try_remove(tmp_gisrc_file)
         return
     else:
         mapsets = mapsets.split(",")
-        Debug.msg(4, "Location <{0}>: {1} mapsets found".format(location, len(mapsets)))
+        Debug.msg(4, "Project <{0}>: {1} mapsets found".format(location, len(mapsets)))
         for each in mapsets:
             maps_dict[each] = []
     if lazy:
@@ -128,7 +119,7 @@ def getLocationTree(gisdbase, location, queue, mapsets=None, lazy=False):
         queue.put(
             (
                 maps_dict,
-                _("Failed to read maps from location <{l}>.").format(l=location),
+                _("Failed to read maps from project <{l}>.").format(l=location),
             )
         )
         gscript.try_remove(tmp_gisrc_file)
@@ -136,7 +127,7 @@ def getLocationTree(gisdbase, location, queue, mapsets=None, lazy=False):
     else:
         # fill dictionary
         listOfMaps = maplist.splitlines()
-        Debug.msg(4, "Location <{0}>: {1} maps found".format(location, len(listOfMaps)))
+        Debug.msg(4, "Project <{0}>: {1} maps found".format(location, len(listOfMaps)))
         for each in listOfMaps:
             ltype, wholename = each.split("/")
             name, mapset = wholename.split("@", maxsplit=1)
@@ -146,98 +137,6 @@ def getLocationTree(gisdbase, location, queue, mapsets=None, lazy=False):
     gscript.try_remove(tmp_gisrc_file)
 
 
-class CurrentMapsetWatch(FileSystemEventHandler):
-    """Monitors rc file to check if mapset has been changed.
-    In that case wx event is dispatched to event handler.
-    Needs to check timestamp, because the modified event is sent twice.
-    This assumes new instance of this class is started
-    whenever mapset is changed."""
-
-    def __init__(self, rcfile, mapset_path, event_handler):
-        FileSystemEventHandler.__init__(self)
-        self.event_handler = event_handler
-        self.mapset_path = mapset_path
-        self.rcfile_name = os.path.basename(rcfile)
-        self.modified_time = 0
-
-    def on_modified(self, event):
-        if (
-            not event.is_directory
-            and os.path.basename(event.src_path) == self.rcfile_name
-        ):
-            timestamp = os.stat(event.src_path).st_mtime
-            if timestamp - self.modified_time < 0.5:
-                return
-            self.modified_time = timestamp
-            # wait to make sure file writing is done
-            time.sleep(0.1)
-            with open(event.src_path, "r") as f:
-                gisrc = {}
-                for line in f.readlines():
-                    key, val = line.split(":")
-                    gisrc[key.strip()] = val.strip()
-                new = os.path.join(
-                    gisrc["GISDBASE"], gisrc["LOCATION_NAME"], gisrc["MAPSET"]
-                )
-                if new != self.mapset_path:
-                    evt = currentMapsetChanged()
-                    wx.PostEvent(self.event_handler, evt)
-
-
-class MapWatch(PatternMatchingEventHandler):
-    """Monitors file events (create, delete, move files) using watchdog
-    to inform about changes in current mapset. One instance monitors
-    only one element (raster, vector, raster_3d).
-    Patterns are not used/needed in this case, use just '*' for matching
-    everything. When file/directory change is detected, wx event is dispatched
-    to event handler (can't use Signals because this is different thread),
-    containing info about the change."""
-
-    def __init__(self, patterns, element, event_handler):
-        PatternMatchingEventHandler.__init__(self, patterns=patterns)
-        self.element = element
-        self.event_handler = event_handler
-
-    def on_created(self, event):
-        if (
-            self.element == "vector" or self.element == "raster_3d"
-        ) and not event.is_directory:
-            return
-        evt = updateMapset(
-            src_path=event.src_path,
-            event_type=event.event_type,
-            is_directory=event.is_directory,
-            dest_path=None,
-        )
-        wx.PostEvent(self.event_handler, evt)
-
-    def on_deleted(self, event):
-        if (
-            self.element == "vector" or self.element == "raster_3d"
-        ) and not event.is_directory:
-            return
-        evt = updateMapset(
-            src_path=event.src_path,
-            event_type=event.event_type,
-            is_directory=event.is_directory,
-            dest_path=None,
-        )
-        wx.PostEvent(self.event_handler, evt)
-
-    def on_moved(self, event):
-        if (
-            self.element == "vector" or self.element == "raster_3d"
-        ) and not event.is_directory:
-            return
-        evt = updateMapset(
-            src_path=event.src_path,
-            event_type=event.event_type,
-            is_directory=event.is_directory,
-            dest_path=event.dest_path,
-        )
-        wx.PostEvent(self.event_handler, evt)
-
-
 class NameEntryDialog(TextEntryDialog):
     def __init__(self, element, mapset, env, **kwargs):
         TextEntryDialog.__init__(self, **kwargs)
@@ -272,11 +171,11 @@ class NameEntryDialog(TextEntryDialog):
             self.EndModal(wx.ID_OK)
 
 
-class DataCatalogNode(DictNode):
+class DataCatalogNode(DictFilterNode):
     """Node representing item in datacatalog."""
 
     def __init__(self, data=None):
-        super(DataCatalogNode, self).__init__(data=data)
+        super().__init__(data=data)
 
     @property
     def label(self):
@@ -298,36 +197,6 @@ class DataCatalogNode(DictNode):
 
         return _("{name}").format(**data)
 
-    def match(self, method="exact", **kwargs):
-        """Method used for searching according to given parameters.
-
-        :param method: 'exact' for exact match or 'filtering' for filtering by type/name
-        :param kwargs key-value to be matched, filtering method uses 'type' and 'name'
-               where 'name' is compiled regex
-        """
-        if not kwargs:
-            return False
-
-        if method == "exact":
-            for key, value in kwargs.items():
-                if not (key in self.data and self.data[key] == value):
-                    return False
-            return True
-        # for filtering
-        if (
-            "type" in kwargs
-            and "type" in self.data
-            and kwargs["type"] != self.data["type"]
-        ):
-            return False
-        if (
-            "name" in kwargs
-            and "name" in self.data
-            and not kwargs["name"].search(self.data["name"])
-        ):
-            return False
-        return True
-
 
 class DataCatalogTree(TreeView):
     """Tree structure visualizing and managing grass database.
@@ -355,9 +224,7 @@ class DataCatalogTree(TreeView):
         """Location Map Tree constructor."""
         self._model = TreeModel(DataCatalogNode)
         self._orig_model = self._model
-        super(DataCatalogTree, self).__init__(
-            parent=parent, model=self._model, id=wx.ID_ANY, style=style
-        )
+        super().__init__(parent=parent, model=self._model, id=wx.ID_ANY, style=style)
 
         self._giface = giface
         self._restricted = True
@@ -390,6 +257,16 @@ class DataCatalogTree(TreeView):
         self._lastWatchdogUpdate = gscript.clock()
         self._updateMapsetWhenIdle = None
 
+        #  mapset watchdog
+        self._mapset_watchdog = MapsetWatchdog(
+            elements_dirs=(
+                ("raster", "cell"),
+                ("vector", "vector"),
+                ("raster_3d", "grid3"),
+            ),
+            evt_handler=self,
+            giface=self._giface,
+        )
         # Get databases from settings
         # add current to settings if it's not included
         self.grassdatabases = self._getValidSavedGrassDBs()
@@ -431,7 +308,6 @@ class DataCatalogTree(TreeView):
         self.Bind(
             EVT_CURRENT_MAPSET_CHANGED, lambda evt: self._updateAfterMapsetChanged()
         )
-        self.observer = None
 
     def _resetSelectVariables(self):
         """Reset variables related to item selection."""
@@ -643,7 +519,7 @@ class DataCatalogTree(TreeView):
 
             Debug.msg(
                 3,
-                "Scanning location <{0}> ({1}/{2})".format(
+                "Scanning project <{0}> ({1}/{2})".format(
                     location, loc_count, nlocations
                 ),
             )
@@ -705,9 +581,11 @@ class DataCatalogTree(TreeView):
         """Updates grass databases, locations, mapsets and layers in the tree.
 
         It runs in thread, so it should not directly interact with GUI.
-        In case of any errors it returns the errors as a list of strings, otherwise None.
+        In case of any errors it returns the errors as a list of strings, otherwise
+        None.
 
-        Option full=True forces full reload, full=False will behave based on user settings.
+        Option full=True forces full reload, full=False will behave based on user
+        settings.
         """
         errors = []
         for grassdatabase in self.grassdatabases:
@@ -730,55 +608,6 @@ class DataCatalogTree(TreeView):
             return errors
         return None
 
-    def ScheduleWatchCurrentMapset(self):
-        """Using watchdog library, sets up watching of current mapset folder
-        to detect changes not captured by other means (e.g. from command line).
-        Schedules 3 watches (raster, vector, 3D raster).
-        If watchdog observers are active, it restarts the observers in current mapset.
-        Also schedules monitoring of rc file to detect mapset change.
-        """
-        global watchdog_used
-        if not watchdog_used:
-            return
-
-        if self.observer and self.observer.is_alive():
-            self.observer.stop()
-            self.observer.join()
-            self.observer.unschedule_all()
-        self.observer = Observer()
-
-        gisenv = gscript.gisenv()
-        mapset_path = os.path.join(
-            gisenv["GISDBASE"], gisenv["LOCATION_NAME"], gisenv["MAPSET"]
-        )
-        rcfile = os.environ["GISRC"]
-        self.observer.schedule(
-            CurrentMapsetWatch(rcfile, mapset_path, self),
-            os.path.dirname(rcfile),
-            recursive=False,
-        )
-        for element, directory in (
-            ("raster", "cell"),
-            ("vector", "vector"),
-            ("raster_3d", "grid3"),
-        ):
-            path = os.path.join(mapset_path, directory)
-            if not os.path.exists(path):
-                try:
-                    os.mkdir(path)
-                except OSError:
-                    pass
-            if os.path.exists(path):
-                self.observer.schedule(
-                    MapWatch("*", element, self), path=path, recursive=False
-                )
-        try:
-            self.observer.start()
-        except OSError:
-            # in case inotify on linux exceeds limits
-            watchdog_used = False
-            return
-
     def _onUpdateMapsetWhenIdle(self, event):
         """When idle, check if current mapset should be reloaded
         because there are skipped update events."""
@@ -909,7 +738,7 @@ class DataCatalogTree(TreeView):
         if event.ret is not None:
             self._giface.WriteWarning("\n".join(event.ret))
         self.UpdateCurrentDbLocationMapsetNode()
-        self.ScheduleWatchCurrentMapset()
+        self._mapset_watchdog.ScheduleWatchCurrentMapset()
         self.RefreshItems()
         self.ExpandCurrentMapset()
         self.loadingDone.emit()
@@ -1043,17 +872,17 @@ class DataCatalogTree(TreeView):
                     dlg = wx.MessageDialog(
                         parent=self,
                         message=_(
-                            "Map <{map_name}@{map_mapset}> is not in the current location. "
-                            "To be able to display it you need to switch to <{map_location}> "
-                            "location. Note that if you switch there all current "
-                            "Map Displays will be closed.\n\n"
+                            "Map <{map_name}@{map_mapset}> is not in the current "
+                            "project. To be able to display it you need to switch to "
+                            "<{map_location}> project. Note that if you switch there "
+                            "all current Map Displays will be closed.\n\n"
                             "Do you want to switch anyway?"
                         ).format(
                             map_name=selected_layer.data["name"],
                             map_mapset=selected_mapset.data["name"],
                             map_location=selected_loc.data["name"],
                         ),
-                        caption=_("Map in a different location"),
+                        caption=_("Map in a different project"),
                         style=wx.YES_NO | wx.NO_DEFAULT | wx.ICON_QUESTION,
                     )
                     dlg.SetYesNoLabels("S&witch", "C&ancel")
@@ -1087,7 +916,7 @@ class DataCatalogTree(TreeView):
             self.Select(item[0], select=True)
             self.ExpandNode(item[0], recursive=False)
         else:
-            Debug.msg(1, "Location <%s> not found" % location)
+            Debug.msg(1, "Project <%s> not found" % location)
 
     def GetCurrentDbLocationMapsetNode(self):
         """Get current mapset node"""
@@ -1391,7 +1220,7 @@ class DataCatalogTree(TreeView):
             )
             self._renameNode(self.selected_location[0], new_name)
             label = _(
-                "Renaming location <{oldlocation}> to <{newlocation}> completed"
+                "Renaming project <{oldlocation}> to <{newlocation}> completed"
             ).format(oldlocation=old_name, newlocation=new_name)
             self.showNotification.emit(message=label)
 
@@ -1510,9 +1339,13 @@ class DataCatalogTree(TreeView):
                 if pasted == 0:
                     Debug.msg(1, "COPIED TO: " + new_name)
                     if self.copy_mode:
-                        self.showNotification.emit(message=_("g.copy completed"))
+                        self.showNotification.emit(message=_("Copying completed"))
                     else:
-                        self.showNotification.emit(message=_("g.copy completed"))
+                        # remove old
+                        self._removeMapAfterCopy(
+                            self.copy_layer[i], self.copy_mapset[i], env2
+                        )
+                        self.showNotification.emit(message=_("Moving completed"))
                     self._giface.grassdbChanged.emit(
                         grassdb=self.selected_grassdb[0].data["name"],
                         location=self.selected_location[0].data["name"],
@@ -1521,11 +1354,6 @@ class DataCatalogTree(TreeView):
                         element=node,
                         action="new",
                     )
-                    # remove old
-                    if not self.copy_mode:
-                        self._removeMapAfterCopy(
-                            self.copy_layer[i], self.copy_mapset[i], env2
-                        )
 
                 gscript.try_remove(gisrc)
                 gscript.try_remove(gisrc2)
@@ -1849,7 +1677,8 @@ class DataCatalogTree(TreeView):
             )
             names[self.selected_layer[i].data["type"]].append(name)
             all_names.append(name)
-        # if self.selected_location[0].data['name'] == gisenv()['LOCATION_NAME'] and self.selected_mapset[0]:
+        # if self.selected_location[0].data['name'] == gisenv()['LOCATION_NAME'] and
+        # self.selected_mapset[0]:
         for ltype in names:
             if names[ltype]:
                 self._giface.lmgr.AddMaps(list(reversed(names[ltype])), ltype, True)
@@ -1885,7 +1714,8 @@ class DataCatalogTree(TreeView):
                 ):
                     GMessage(
                         _(
-                            "To move or copy maps to other mapsets, unlock editing of other mapsets"
+                            "To move or copy maps to other mapsets, unlock editing of "
+                            "other mapsets"
                         ),
                         parent=self,
                     )
@@ -1898,9 +1728,9 @@ class DataCatalogTree(TreeView):
             else:
                 GMessage(
                     _(
-                        "To move or copy maps to other location, "
+                        "To move or copy maps to other project, "
                         "please drag them to a mapset in the "
-                        "destination location"
+                        "destination project"
                     ),
                     parent=self,
                 )
@@ -2050,7 +1880,7 @@ class DataCatalogTree(TreeView):
         self.RefreshNode(self.current_mapset_node, recursive=True)
         self.ExpandCurrentMapset()
         self.RefreshItems()
-        self.ScheduleWatchCurrentMapset()
+        self._mapset_watchdog.ScheduleWatchCurrentMapset()
 
     def OnMetadata(self, event):
         """Show metadata of any raster/vector/3draster"""
@@ -2334,13 +2164,13 @@ class DataCatalogTree(TreeView):
         menu.AppendItem(item)
         self.Bind(wx.EVT_MENU, self.OnCreateMapset, item)
 
-        item = wx.MenuItem(menu, wx.ID_ANY, _("&Delete location"))
+        item = wx.MenuItem(menu, wx.ID_ANY, _("&Delete project"))
         menu.AppendItem(item)
         self.Bind(wx.EVT_MENU, self.OnDeleteLocation, item)
         if self._restricted:
             item.Enable(False)
 
-        item = wx.MenuItem(menu, wx.ID_ANY, _("&Rename location"))
+        item = wx.MenuItem(menu, wx.ID_ANY, _("&Rename project"))
         menu.AppendItem(item)
         self.Bind(wx.EVT_MENU, self.OnRenameLocation, item)
         if self._restricted:
@@ -2359,11 +2189,11 @@ class DataCatalogTree(TreeView):
         genv = gisenv()
         currentGrassDb, currentLocation, currentMapset = self._isCurrent(genv)
 
-        item = wx.MenuItem(menu, wx.ID_ANY, _("&Create new location"))
+        item = wx.MenuItem(menu, wx.ID_ANY, _("&Create new project (location)"))
         menu.AppendItem(item)
         self.Bind(wx.EVT_MENU, self.OnCreateLocation, item)
 
-        item = wx.MenuItem(menu, wx.ID_ANY, _("&Download sample location"))
+        item = wx.MenuItem(menu, wx.ID_ANY, _("&Download sample project (location)"))
         menu.AppendItem(item)
         self.Bind(wx.EVT_MENU, self.OnDownloadLocation, item)
 
@@ -2405,7 +2235,7 @@ class DataCatalogTree(TreeView):
     def _popupMenuMultipleLocations(self):
         """Create popup menu for multiple selected locations"""
         menu = Menu()
-        item = wx.MenuItem(menu, wx.ID_ANY, _("&Delete locations"))
+        item = wx.MenuItem(menu, wx.ID_ANY, _("&Delete projects (locations)"))
         menu.AppendItem(item)
         self.Bind(wx.EVT_MENU, self.OnDeleteLocation, item)
         if self._restricted:
