@@ -44,7 +44,7 @@ class SwipeBufferedWindow(BufferedMapWindow):
         )
         Debug.msg(2, "SwipeBufferedWindow.__init__()")
 
-        self.specialSize = super(SwipeBufferedWindow, self).GetClientSize()
+        self.specialSize = super().GetClientSize()
         self.specialCoords = [0, 0]
         self.imageId = 99
         self.movingSash = False
@@ -82,7 +82,7 @@ class SwipeBufferedWindow(BufferedMapWindow):
         if self._mode == "swipe":
             return self.specialSize
         else:
-            return super(SwipeBufferedWindow, self).GetClientSize()
+            return super().GetClientSize()
 
     def SetClientSize(self, size):
         """Overridden method which sets simulated window size."""
@@ -116,7 +116,7 @@ class SwipeBufferedWindow(BufferedMapWindow):
         """Calls superclass's OnSize method only when needed"""
         Debug.msg(5, "SwipeBufferedWindow.OnSize()")
         if not self.movingSash:
-            super(SwipeBufferedWindow, self).OnSize(event)
+            super().OnSize(event)
 
     def Draw(
         self,
@@ -134,9 +134,7 @@ class SwipeBufferedWindow(BufferedMapWindow):
         if pdctype == "image":
             coords = self.GetImageCoords()
 
-        return super(SwipeBufferedWindow, self).Draw(
-            pdc, img, drawid, pdctype, coords, pen, brush
-        )
+        return super().Draw(pdc, img, drawid, pdctype, coords, pen, brush)
 
     def OnLeftDown(self, event):
         """Left mouse button pressed.
@@ -157,7 +155,7 @@ class SwipeBufferedWindow(BufferedMapWindow):
             if idlist:
                 self.dragid = idlist[0]  # drag whatever is on top
         else:
-            super(SwipeBufferedWindow, self).OnLeftDown(event)
+            super().OnLeftDown(event)
 
     def OnDragging(self, event):
         """Mouse dragging - overlay (text) is moving.
@@ -169,7 +167,7 @@ class SwipeBufferedWindow(BufferedMapWindow):
             imX, imY = self.GetImageCoords()
             self.DragItem(self.dragid, (evX + imX, evY + imY))
         else:
-            super(SwipeBufferedWindow, self).OnDragging(event)
+            super().OnDragging(event)
 
     def TranslateImage(self, dx, dy):
         """Translate image and redraw."""
@@ -201,7 +199,7 @@ class SwipeBufferedWindow(BufferedMapWindow):
         offsetX, offsetY = self.GetImageCoords()
         begin = (self.mouse["begin"][0] + offsetX, self.mouse["begin"][1] + offsetY)
         end = (self.mouse["end"][0] + offsetX, self.mouse["end"][1] + offsetY)
-        super(SwipeBufferedWindow, self).MouseDraw(pdc, begin, end)
+        super().MouseDraw(pdc, begin, end)
 
     def DrawMouseCursor(self, coords):
         """Draw moving cross."""
