@@ -19,20 +19,20 @@
 #
 ############################################################################
 
-#%module
-#% description: Allows comparing temporal datasets by displaying their temporal extents in a plot.
-#% keyword: general
-#% keyword: GUI
-#% keyword: temporal
-#% keywords: plot
-#%end
-#%option G_OPT_STDS_INPUTS
-#% required: no
-#%end
-#%flag
-#% key: 3
-#% description: Show also 3D plot of spatio-temporal extents
-#%end
+# %module
+# % description: Allows comparing temporal datasets by displaying their temporal extents in a plot.
+# % keyword: general
+# % keyword: GUI
+# % keyword: temporal
+# % keywords: plot
+# %end
+# %option G_OPT_STDS_INPUTS
+# % required: no
+# %end
+# %flag
+# % key: 3
+# % description: Show also 3D plot of spatio-temporal extents
+# %end
 
 import grass.script as gscript
 
@@ -43,6 +43,7 @@ def main():
     import wx
 
     from grass.script.setup import set_gui_path
+
     set_gui_path()
 
     try:
@@ -53,17 +54,20 @@ def main():
         # user in a nice way
         gscript.fatal(str(e))
 
-    datasets = options['inputs'].strip().split(',')
+    datasets = options["inputs"].strip().split(",")
     datasets = [data for data in datasets if data]
-    view3d = flags['3']
+    view3d = flags["3"]
 
     app = wx.App()
-    frame = TimelineFrame(None)
+    frame = TimelineFrame(
+        parent=None,
+        title=_("Timeline Tool - GRASS GIS"),
+    )
     frame.SetDatasets(datasets)
     frame.Show3D(view3d)
     frame.Show()
     app.MainLoop()
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
