@@ -19,16 +19,11 @@ Usage: python support/update_menudata.py [-d]
 @author Martin Landa <landa.martin gmail.com>
 """
 
-from __future__ import print_function
-
 import os
 import sys
 import tempfile
 
-try:
-    import xml.etree.ElementTree as etree
-except ImportError:
-    import elementtree.ElementTree as etree  # Python <= 2.4
+import xml.etree.ElementTree as etree
 
 from grass.script import core as grass
 from grass.script import task as gtask
@@ -120,7 +115,7 @@ def writeData(data, file=None):
 
     try:
         data.tree.write(file)
-    except IOError:
+    except OSError:
         print(
             "'%s' not found." " Please run the script from 'gui/wxpython'." % file,
             file=sys.stderr,
@@ -133,7 +128,7 @@ def writeData(data, file=None):
             f.write("\n")
         finally:
             f.close()
-    except IOError:
+    except OSError:
         print("ERROR: Unable to write to menudata file.", file=sys.stderr)
 
 
