@@ -52,7 +52,9 @@ def main():
     set_gui_path()
 
     from core.render import Map
-    from mapdisp.frame import MapFrame
+    from core.globalvar import ICONDIR
+    from mapdisp.frame import MapPanel
+    from gui_core.mapdisp import FrameMixin
     from mapdisp.main import DMonGrassInterface
     from core.settings import UserSettings
     from vdigit.main import haveVDigit, errorMsg
@@ -60,16 +62,28 @@ def main():
 
     # define classes which needs imports as local
     # for longer definitions, a separate file would be a better option
-    class VDigitMapFrame(MapFrame):
-        def __init__(self, vectorMap):
-            MapFrame.__init__(
-                self,
-                parent=None,
-                Map=Map(),
-                giface=DMonGrassInterface(None),
-                title=_("Vector Digitizer - GRASS GIS"),
-                size=(850, 600),
+    class VDigitMapDisplay(FrameMixin, MapPanel):
+        """Map display for wrapping map panel with v.digit mathods and frame methods"""
+
+        def __init__(self, parent, vectorMap):
+            MapPanel.__init__(
+                self, parent=parent, Map=Map(), giface=DMonGrassInterface(None)
             )
+
+            # set system icon
+            parent.SetIcon(
+                wx.Icon(os.path.join(ICONDIR, "grass_map.ico"), wx.BITMAP_TYPE_ICO)
+            )
+
+            # bindings
+            parent.Bind(wx.EVT_CLOSE, self.OnCloseWindow)
+
+            # extend shortcuts and create frame accelerator table
+            self.shortcuts_table.append(
+                (self.OnFullScreen, wx.ACCEL_NORMAL, wx.WXK_F11)
+            )
+            self._initShortcuts()
+
             # this giface issue not solved yet, we must set mapframe aferwards
             self._giface._mapframe = self
             # load vector map
@@ -92,6 +106,12 @@ def main():
             self.toolbars["vdigit"].quitDigitizer.disconnect(self.QuitVDigit)
             self.toolbars["vdigit"].quitDigitizer.connect(lambda: self.Close())
 
+            # add Map Display panel to Map Display frame
+            sizer = wx.BoxSizer(wx.VERTICAL)
+            sizer.Add(self, proportion=1, flag=wx.EXPAND)
+            parent.SetSizer(sizer)
+            parent.Layout()
+
     if not haveVDigit:
         grass.fatal(_("Vector digitizer not available. %s") % errorMsg)
 
@@ -123,7 +143,14 @@ def main():
         os.environ["GRASS_RENDER_IMMEDIATE"] = "cairo"
 
     app = wx.App()
-    frame = VDigitMapFrame(options["map"])
+    frame = wx.Frame(
+        None,
+        id=wx.ID_ANY,
+        size=(850, 600),
+        style=wx.DEFAULT_FRAME_STYLE,
+        title=_("Vector Digitizer - GRASS GIS"),
+    )
+    frame = VDigitMapDisplay(parent=frame, vectorMap=options["map"])
     frame.Show()
 
     app.MainLoop()
