@@ -15,21 +15,25 @@ This program is free software under the GNU General Public License
 """
 
 try:
-    from vdigit.wxdigit import IVDigit, GV_LINES, CFUNCTYPE
+    from vdigit.wxdigit import IVDigit, GV_LINES, CFUNCTYPE  # noqa: F401
+
     haveVDigit = True
-    errorMsg   = ''
+    errorMsg = ""
 except (ImportError, NameError) as err:
     haveVDigit = False
-    errorMsg   = err
-    GV_LINES   = -1
+    errorMsg = err
+    GV_LINES = -1
+
     class IVDigit:
         def __init__(self):
             pass
 
+
 class VDigit(IVDigit):
-    def __init__(self, mapwindow):
+    def __init__(self, giface, mapwindow):
         """Base class of vector digitizer
 
+        :param giface: reference to a grass interface instance
         :param mapwindow: reference to a map window instance
         """
-        IVDigit.__init__(self, mapwindow)
+        IVDigit.__init__(self, giface, mapwindow)
