@@ -1,15 +1,15 @@
-
 /****************************************************************************
  *
  * MODULE:       i.aster.toar
  * AUTHOR(S):    Yann Chemin - yann.chemin@gmail.com
  * PURPOSE:      Calculate TOA Reflectance for Aster from DN.
- * 		 Input 9 bands (VNIR and SWIR).
+ *               Input 9 bands (VNIR and SWIR).
  *
  * COPYRIGHT:    (C) 2002-2010 by the GRASS Development Team
  *
- *               This program is free software under the GNU Lesser General Public
- *   	    	 License. Read the file COPYING that comes with GRASS for details.
+ *               This program is free software under the GNU Lesser General
+ *               Public License. Read the file COPYING that comes with GRASS
+ *               for details.
  *
  *****************************************************************************/
 
@@ -25,11 +25,11 @@
 /* DN to radiance conversion factors */
 double gain_aster(int band_number, int gain_code);
 
-    /*Gain Code */
-    /*0 - High (Not Applicable for band 10-14: TIR) */
-    /*1 - Normal */
-    /*2 - Low 1(Not Applicable for band 10-14: TIR) */
-    /*3 - Low 2(Not Applicable for Band 1-3N/B & 10-14) */
+/*Gain Code */
+/*0 - High (Not Applicable for band 10-14: TIR) */
+/*1 - Normal */
+/*2 - Low 1(Not Applicable for band 10-14: TIR) */
+/*3 - Low 2(Not Applicable for Band 1-3N/B & 10-14) */
 
 /*sun exo-atmospheric irradiance */
 #define KEXO1 1828.0
@@ -42,14 +42,14 @@ double gain_aster(int band_number, int gain_code);
 #define KEXO8 66.41
 #define KEXO9 59.83
 
-#define PI M_PI
+#define PI    M_PI
 
 double rad2ref_aster(double radiance, double doy, double sun_elevation,
                      double k_exo);
 
 int main(int argc, char *argv[])
 {
-    struct Cell_head cellhd;    /*region+header info */
+    struct Cell_head cellhd; /*region+header info */
     int nrows, ncols;
     int row, col;
     struct GModule *module;
@@ -59,8 +59,8 @@ int main(int argc, char *argv[])
     struct Flag *flag3, *flag4, *flag5;
 
     /************************************/
-    char *name;                 /*input raster name */
-    char *result;               /*output raster name */
+    char *name;   /*input raster name */
+    char *result; /*output raster name */
 
     /*Prepare new names for output files */
     char result0[GNAME_MAX], result1[GNAME_MAX];
@@ -75,7 +75,7 @@ int main(int argc, char *argv[])
     /*File Descriptors */
     int infd[MAXFILES];
     int outfd[MAXFILES];
-    char **names, **ptr;
+    char **ptr;
 
     /* For some strange reason infd[0] cannot be used later */
     /* So nfiles is initialized with nfiles = 1 */
@@ -86,7 +86,7 @@ int main(int argc, char *argv[])
     DCELL *outrast[MAXFILES];
     RASTER_MAP_TYPE in_data_type[MAXFILES];
     RASTER_MAP_TYPE out_data_type = DCELL_TYPE; /* 0=numbers  1=text */
-    double gain[MAXFILES]; /* , offset[MAXFILES]; */
+    double gain[MAXFILES];                      /* , offset[MAXFILES]; */
     double kexo[MAXFILES];
     double doy, sun_elevation;
 
@@ -101,7 +101,8 @@ int main(int argc, char *argv[])
     G_add_keyword(_("satellite"));
     G_add_keyword(_("ASTER"));
     module->description =
-        _("Calculates Top of Atmosphere Radiance/Reflectance/Brightness Temperature from ASTER DN.");
+        _("Calculates Top of Atmosphere Radiance/Reflectance/Brightness "
+          "Temperature from ASTER DN.");
 
     /* Define the different options */
     input = G_define_standard_option(G_OPT_R_INPUTS);
@@ -153,7 +154,6 @@ int main(int argc, char *argv[])
     if (G_parser(argc, argv))
         exit(EXIT_FAILURE);
 
-    names = input->answers;
     ptr = input->answers;
     doy = atof(input1->answer);
     sun_elevation = atof(input2->answer);
@@ -227,8 +227,7 @@ int main(int argc, char *argv[])
     /********************/
     for (; *ptr != NULL; ptr++) {
         if (nfiles == MAXFILES)
-            G_fatal_error(_("Too many input maps. Only %d allowed."),
-                          MAXFILES);
+            G_fatal_error(_("Too many input maps. Only %d allowed."), MAXFILES);
         name = *ptr;
         /* Allocate input buffer */
         in_data_type[nfiles] = Rast_map_type(name, "");
@@ -280,13 +279,13 @@ int main(int argc, char *argv[])
             for (i = 0; i < MAXFILES; i++) {
                 switch (in_data_type[i]) {
                 case CELL_TYPE:
-                    d[i] = (double)((CELL *) inrast[i])[col];
+                    d[i] = (double)((CELL *)inrast[i])[col];
                     break;
                 case FCELL_TYPE:
-                    d[i] = (double)((FCELL *) inrast[i])[col];
+                    d[i] = (double)((FCELL *)inrast[i])[col];
                     break;
                 case DCELL_TYPE:
-                    d[i] = (double)((DCELL *) inrast[i])[col];
+                    d[i] = (double)((DCELL *)inrast[i])[col];
                     break;
                 }
                 /* if radiance mode or Thermal band */
