@@ -75,9 +75,12 @@ extern int hist_n;
 void acca_algorithm(Gfile *out, Gfile band[], int single_pass, int with_shadow,
                     int cloud_signature)
 {
-    int i, count[5], hist_cold[hist_n], hist_warm[hist_n];
+    int i, count[5];
     double max, value[5], signa[5], idesert, review_warm, shift;
 
+    int *hist_cold = G_malloc(hist_n * sizeof(int));
+    int *hist_warm = G_malloc(hist_n * sizeof(int));
+
     /* Reset variables ... */
     for (i = 0; i < 5; i++) {
         count[i] = 0;
@@ -213,6 +216,9 @@ void acca_algorithm(Gfile *out, Gfile band[], int single_pass, int with_shadow,
     acca_second(out, band[BAND6], review_warm, value[KUPPER], value[KLOWER]);
     /* CATEGORIES: IS_WARM_CLOUD, IS_COLD_CLOUD, IS_SHADOW, NULL (= NO_CLOUD) */
 
+    G_free(hist_cold);
+    G_free(hist_warm);
+
     return;
 }
 
