@@ -1,25 +1,22 @@
 #include <stdio.h>
 #include <math.h>
 
-
 double *Cdhc_kotz_families(double *x, int n)
 {
     static double y[2];
     int i;
-    double a1, b1, a2, b3, c1, c2, c3, c4, c5, c6, lx;
-    double sum1 = 0.0, sum2 = 0.0, sum4 = 0.0;
+    double a1, a2, b3, c1, c2, c3, c4, c5, c6, lx;
+    double sum2 = 0.0, sum4 = 0.0;
 
     for (i = 0; i < n; ++i) {
-	sum1 += x[i];
-	sum2 += log(x[i]);
+        sum2 += log(x[i]);
     }
 
-    b1 = sum1 / n;
     a1 = sum2 / n;
 
     for (i = 0; i < n; ++i) {
-	lx = log(x[i]);
-	sum4 += (lx - a1) * (lx - a1);
+        lx = log(x[i]);
+        sum4 += (lx - a1) * (lx - a1);
     }
 
     a2 = sum4 / n;
@@ -32,14 +29,14 @@ double *Cdhc_kotz_families(double *x, int n)
 
     if (c2 < c5) {
 #ifdef NOISY
-	fprintf(stdout, "  WARNING!!! STATISTICS FOR THE NEXT TEST WILL\n");
-	fprintf(stdout, "  NOT BE CALCULATED DUE TO SMALL LOGVARIANCE\n");
+        fprintf(stdout, "  WARNING!!! STATISTICS FOR THE NEXT TEST WILL\n");
+        fprintf(stdout, "  NOT BE CALCULATED DUE TO SMALL LOGVARIANCE\n");
 #endif /* NOISY */
-	y[0] = 999999999.;
+        y[0] = 999999999.;
     }
     else {
-	c6 = sqrt(c2 - c5) * 2.0 * sqrt((double)n);
-	y[0] = c1 / c6;
+        c6 = sqrt(c2 - c5) * 2.0 * sqrt((double)n);
+        y[0] = c1 / c6;
     }
 
 #ifdef NOISY
