@@ -1,6 +1,6 @@
 /*!
  * \file db/dbmi_client/c_finddb.c
- * 
+ *
  * \brief DBMI Library (client) - find database
  *
  * (C) 1999-2008 by the GRASS Development Team
@@ -17,16 +17,16 @@
 #include "macros.h"
 
 /*!
-  \brief Find database
+   \brief Find database
 
-  \param driver db driver
-  \param handle handle info
-  \param[out] found if non-zero database found
+   \param driver db driver
+   \param handle handle info
+   \param[out] found if non-zero database found
 
-  \return DB_OK on success
-  \return DB_FAILED on failure
+   \return DB_OK on success
+   \return DB_FAILED on failure
  */
-int db_find_database(dbDriver * driver, dbHandle * handle, int *found)
+int db_find_database(dbDriver *driver, dbHandle *handle, int *found)
 {
     int ret_code;
     int stat;
@@ -43,19 +43,17 @@ int db_find_database(dbDriver * driver, dbHandle * handle, int *found)
     DB_RECV_RETURN_CODE(&ret_code);
 
     if (ret_code != DB_OK)
-	return ret_code;	/* ret_code SHOULD == DB_FAILED */
+        return ret_code; /* ret_code SHOULD == DB_FAILED */
 
     /* get results */
     DB_RECV_INT(found);
 
     stat = DB_OK;
     if (*found) {
-	DB_RECV_HANDLE(&temp);
-	stat = db_set_handle(handle,
-			     db_get_handle_dbname(&temp),
-			     db_get_handle_dbschema(&temp)
-	    );
-	db_free_handle(&temp);
+        DB_RECV_HANDLE(&temp);
+        stat = db_set_handle(handle, db_get_handle_dbname(&temp),
+                             db_get_handle_dbschema(&temp));
+        db_free_handle(&temp);
     }
     return stat;
 }
