@@ -1,6 +1,6 @@
 /*!
  * \file db/dbmi_driver/d_bindupdate.c
- * 
+ *
  * \brief DBMI Library (driver) - bind update
  *
  * (C) 1999-2008 by the GRASS Development Team
@@ -17,12 +17,12 @@
 #include "dbstubs.h"
 
 /*!
-  \brief ADD
+   \brief ADD
 
-  \return DB_OK on success
-  \return DB_FAILED on failure
+   \return DB_OK on success
+   \return DB_FAILED on failure
  */
-int db_d_bind_update()
+int db_d_bind_update(void)
 {
     dbToken token;
     dbCursor *cursor;
@@ -31,17 +31,17 @@ int db_d_bind_update()
 
     /* get the arg(s) */
     DB_RECV_TOKEN(&token);
-    cursor = (dbCursor *) db_find_token(token);
+    cursor = (dbCursor *)db_find_token(token);
     if (cursor == NULL || !db_test_cursor_type_update(cursor)) {
-	db_error("** not an update cursor **");
-	DB_SEND_FAILURE();
-	return DB_FAILED;
+        db_error("** not an update cursor **");
+        DB_SEND_FAILURE();
+        return DB_FAILED;
     }
     DB_RECV_SHORT_ARRAY(&cursor->column_flags, &ncols);
     if (!db_test_cursor_any_column_flag(cursor)) {
-	db_error("** no columns set in cursor for binding **");
-	DB_SEND_FAILURE();
-	return DB_FAILED;
+        db_error("** no columns set in cursor for binding **");
+        DB_SEND_FAILURE();
+        return DB_FAILED;
     }
 
     /* call the procedure */
@@ -49,8 +49,8 @@ int db_d_bind_update()
 
     /* send the return code */
     if (stat != DB_OK) {
-	DB_SEND_FAILURE();
-	return DB_OK;
+        DB_SEND_FAILURE();
+        return DB_OK;
     }
     DB_SEND_SUCCESS();
 
