@@ -1,32 +1,31 @@
-
 /*****************************************************************************
-*
-* MODULE:       SQL statement parser library 
-*   	    	
-* AUTHOR(S):    lex.l and yac.y were originally taken from unixODBC and
-*               probably written by Peter Harvey <pharvey@codebydesigns.com>,
-*               original modifications & added code by 
-*                     Radim Blazek <radim.blazek gmail.com>
-*               Glynn Clements <glynn gclements.plus.com>,
-*               Markus Neteler <neteler itc.it>,
-*               Martin Landa <landa.martin gmail.com>,
-*               Moritz Lennert <mlennert club.worldonline.be>,
-*               Hamish Bowman <hamish_b yahoo.com>,
-*               Daniel Calvelo Aros <dca.gis gmail.com>,
-*               Paul Kelly <paul-grass stjohnspoint.co.uk>,
-*               Alex Shevlakov <sixote yahoo.com>
-*
-* PURPOSE:      Parse input string containing SQL statement to 
-*               SQLPSTMT structure.
-*               SQL parser may be used by simple database drivers. 
-*
-* COPYRIGHT:    (C) 2000-2007 by the GRASS Development Team
-*
-*               This program is free software under the GNU General Public
-*   	    	License (>=v2). Read the file COPYING that comes with GRASS
-*   	    	for details.
-*
-*****************************************************************************/
+ *
+ * MODULE:       SQL statement parser library
+ *
+ * AUTHOR(S):    lex.l and yac.y were originally taken from unixODBC and
+ *               probably written by Peter Harvey <pharvey@codebydesigns.com>,
+ *               original modifications & added code by
+ *                     Radim Blazek <radim.blazek gmail.com>
+ *               Glynn Clements <glynn gclements.plus.com>,
+ *               Markus Neteler <neteler itc.it>,
+ *               Martin Landa <landa.martin gmail.com>,
+ *               Moritz Lennert <mlennert club.worldonline.be>,
+ *               Hamish Bowman <hamish_b yahoo.com>,
+ *               Daniel Calvelo Aros <dca.gis gmail.com>,
+ *               Paul Kelly <paul-grass stjohnspoint.co.uk>,
+ *               Alex Shevlakov <sixote yahoo.com>
+ *
+ * PURPOSE:      Parse input string containing SQL statement to
+ *               SQLPSTMT structure.
+ *               SQL parser may be used by simple database drivers.
+ *
+ * COPYRIGHT:    (C) 2000-2007 by the GRASS Development Team
+ *
+ *               This program is free software under the GNU General Public
+ *               License (>=v2). Read the file COPYING that comes with
+ *               GRASS for details.
+ *
+ *****************************************************************************/
 
 #include <stdlib.h>
 #include <stdio.h>
@@ -38,7 +37,7 @@
 SQLPSTMT *sqlpStmt;
 
 /* save string to value */
-int sqpSaveStr(SQLPVALUE * val, char *c)
+int sqpSaveStr(SQLPVALUE *val, char *c)
 {
     int len = 0;
 
@@ -50,7 +49,7 @@ int sqpSaveStr(SQLPVALUE * val, char *c)
     return (1);
 }
 
-void sqpInitValue(SQLPVALUE * val)
+void sqpInitValue(SQLPVALUE *val)
 {
     val->type = SQLP_NULL;
     val->s = NULL;
@@ -58,21 +57,21 @@ void sqpInitValue(SQLPVALUE * val)
     val->d = 0.0;
 }
 
-void sqpCopyValue(SQLPVALUE * from, SQLPVALUE * to)
+void sqpCopyValue(SQLPVALUE *from, SQLPVALUE *to)
 {
     to->type = from->type;
 
     if (to->s)
-	free(to->s);
+        free(to->s);
 
     if (from->s)
-	to->s = strdup(from->s);
+        to->s = strdup(from->s);
 
     to->i = from->i;
     to->d = from->d;
 }
 
-int sqpInitParser(SQLPSTMT * st)
+int sqpInitParser(SQLPSTMT *st)
 {
     sqlpStmt = st;
     sqlpStmt->cur = sqlpStmt->stmt;
@@ -138,21 +137,21 @@ void sqpValue(char *strval, int intval, double dblval, int type)
 
     sqpAllocVal(sqlpStmt, i + 1);
     sqlpStmt->Val[i].s = NULL;
-    sqlpStmt->Val[i].i = 0;	/* not necessay I think */
-    sqlpStmt->Val[i].d = 0.0;	/* not necessay I think */
+    sqlpStmt->Val[i].i = 0;   /* not necessary I think */
+    sqlpStmt->Val[i].d = 0.0; /* not necessary I think */
 
     sqlpStmt->Val[i].type = type;
     switch (type) {
     case (SQLP_S):
-	sqpSaveStr(&(sqlpStmt->Val[i]), strval);
-	break;
+        sqpSaveStr(&(sqlpStmt->Val[i]), strval);
+        break;
     case (SQLP_I):
-	sqlpStmt->Val[i].i = intval;
-	break;
+        sqlpStmt->Val[i].i = intval;
+        break;
     case (SQLP_D):
-	sqlpStmt->Val[i].d = dblval;
-	break;
-	/* SQLP_NULL, nothing to do */
+        sqlpStmt->Val[i].d = dblval;
+        break;
+        /* SQLP_NULL, nothing to do */
     }
 
     sqlpStmt->nVal++;
@@ -160,7 +159,7 @@ void sqpValue(char *strval, int intval, double dblval, int type)
 }
 
 void sqpAssignment(char *col, char *strval, int intval, double dblval,
-		   SQLPNODE * expval, int type)
+                   SQLPNODE *expval, int type)
 {
     int i;
 
@@ -171,25 +170,25 @@ void sqpAssignment(char *col, char *strval, int intval, double dblval,
 
     sqpAllocVal(sqlpStmt, i + 1);
     sqlpStmt->Val[i].s = NULL;
-    sqlpStmt->Val[i].i = 0;	/* not necessay I think */
-    sqlpStmt->Val[i].d = 0.0;	/* not necessay I think */
+    sqlpStmt->Val[i].i = 0;   /* not necessary I think */
+    sqlpStmt->Val[i].d = 0.0; /* not necessary I think */
 
     sqlpStmt->Val[i].type = type;
     switch (type) {
     case (SQLP_S):
-	sqpSaveStr(&(sqlpStmt->Val[i]), strval);
-	break;
+        sqpSaveStr(&(sqlpStmt->Val[i]), strval);
+        break;
     case (SQLP_I):
-	sqlpStmt->Val[i].i = intval;
-	break;
+        sqlpStmt->Val[i].i = intval;
+        break;
     case (SQLP_D):
-	sqlpStmt->Val[i].d = dblval;
-	break;
+        sqlpStmt->Val[i].d = dblval;
+        break;
     case (SQLP_EXPR):
-	sqlpStmt->Val[i].expr = expval;
-	/* Don't do anything right now; come back to this when executing */
-	break;
-	/* SQLP_NULL, nothing to do */
+        sqlpStmt->Val[i].expr = expval;
+        /* Don't do anything right now; come back to this when executing */
+        break;
+        /* SQLP_NULL, nothing to do */
     }
 
     sqlpStmt->nCol++;
@@ -210,11 +209,11 @@ SQLPNODE *sqpNewNode(void)
 {
     SQLPNODE *np;
 
-    np = (SQLPNODE *) calloc(1, sizeof(SQLPNODE));
+    np = (SQLPNODE *)calloc(1, sizeof(SQLPNODE));
     return np;
 }
 
-SQLPNODE *sqpNewExpressionNode(int oper, SQLPNODE * left, SQLPNODE * right)
+SQLPNODE *sqpNewExpressionNode(int oper, SQLPNODE *left, SQLPNODE *right)
 {
     SQLPNODE *np;
 
@@ -250,29 +249,29 @@ SQLPNODE *sqpNewValueNode(char *strval, int intval, double dblval, int type)
 
     np->value.type = type;
     if (strval)
-	np->value.s = strdup(strval);
+        np->value.s = strdup(strval);
     np->value.i = intval;
     np->value.d = dblval;
 
     return np;
 }
 
-void sqpFreeNode(SQLPNODE * np)
+void sqpFreeNode(SQLPNODE *np)
 {
     if (!np)
-	return;
+        return;
 
     if (np->left)
-	sqpFreeNode(np->left);
+        sqpFreeNode(np->left);
 
     if (np->right)
-	sqpFreeNode(np->right);
+        sqpFreeNode(np->right);
 
     if (np->column_name)
-	free(np->column_name);
+        free(np->column_name);
 
     if (np->value.s)
-	free(np->value.s);
+        free(np->value.s);
 
     free(np);
 }
@@ -285,38 +284,38 @@ int sqpOperatorCode(char *oper)
     tmp = strdup(oper);
     ptr = tmp;
     while (*ptr) {
-	*ptr = tolower(*ptr);
-	ptr++;
+        *ptr = tolower(*ptr);
+        ptr++;
     }
 
     if (strcmp(oper, "=") == 0)
-	return SQLP_EQ;
+        return SQLP_EQ;
     else if (strcmp(oper, "<") == 0)
-	return SQLP_LT;
+        return SQLP_LT;
     else if (strcmp(oper, "<=") == 0)
-	return SQLP_LE;
+        return SQLP_LE;
     else if (strcmp(oper, ">") == 0)
-	return SQLP_GT;
+        return SQLP_GT;
     else if (strcmp(oper, ">=") == 0)
-	return SQLP_GE;
+        return SQLP_GE;
     else if (strcmp(oper, "<>") == 0)
-	return SQLP_NE;
+        return SQLP_NE;
     else if (strcmp(oper, "~") == 0)
-	return SQLP_MTCH;
+        return SQLP_MTCH;
     else if (strcmp(oper, "+") == 0)
-	return SQLP_ADD;
+        return SQLP_ADD;
     else if (strcmp(oper, "-") == 0)
-	return SQLP_SUBTR;
+        return SQLP_SUBTR;
     else if (strcmp(oper, "*") == 0)
-	return SQLP_MLTP;
+        return SQLP_MLTP;
     else if (strcmp(oper, "/") == 0)
-	return SQLP_DIV;
+        return SQLP_DIV;
     else if (strcmp(oper, "and") == 0)
-	return SQLP_AND;
+        return SQLP_AND;
     else if (strcmp(oper, "or") == 0)
-	return SQLP_OR;
+        return SQLP_OR;
     else if (strcmp(oper, "not") == 0)
-	return SQLP_NOT;
+        return SQLP_NOT;
 
     free(tmp);
 
@@ -327,47 +326,47 @@ char *sqpOperatorName(int oper)
 {
     switch (oper) {
     case SQLP_EQ:
-	return "=";
-	break;
+        return "=";
+        break;
     case SQLP_LT:
-	return "<";
-	break;
+        return "<";
+        break;
     case SQLP_LE:
-	return "<=";
-	break;
+        return "<=";
+        break;
     case SQLP_GT:
-	return ">";
-	break;
+        return ">";
+        break;
     case SQLP_GE:
-	return ">=";
-	break;
+        return ">=";
+        break;
     case SQLP_NE:
-	return "<>";
-	break;
+        return "<>";
+        break;
     case SQLP_MTCH:
-	return "~";
-	break;
+        return "~";
+        break;
     case SQLP_ADD:
-	return "+";
-	break;
+        return "+";
+        break;
     case SQLP_SUBTR:
-	return "-";
-	break;
+        return "-";
+        break;
     case SQLP_MLTP:
-	return "*";
-	break;
+        return "*";
+        break;
     case SQLP_DIV:
-	return "/";
-	break;
+        return "/";
+        break;
     case SQLP_AND:
-	return "AND";
-	break;
+        return "AND";
+        break;
     case SQLP_OR:
-	return "OR";
-	break;
+        return "OR";
+        break;
     case SQLP_NOT:
-	return "NOT";
-	break;
+        return "NOT";
+        break;
     }
     return "?";
 }
