@@ -13,15 +13,15 @@
 void COM_begin_raster(int mask, int src[2][2], double dst[2][2])
 {
     if (driver->Begin_raster)
-	(*driver->Begin_raster) (mask, src, dst);
+        (*driver->Begin_raster)(mask, src, dst);
 }
 
-int COM_raster(int n, int row,
-	       const unsigned char *red, const unsigned char *grn,
-	       const unsigned char *blu, const unsigned char *nul)
+int COM_raster(int n, int row, const unsigned char *red,
+               const unsigned char *grn, const unsigned char *blu,
+               const unsigned char *nul)
 {
     if (driver->Raster)
-	return (*driver->Raster) (n, row, red, grn, blu, nul);
+        return (*driver->Raster)(n, row, red, grn, blu, nul);
 
     return -1;
 }
@@ -29,5 +29,5 @@ int COM_raster(int n, int row,
 void COM_end_raster(void)
 {
     if (driver->End_raster)
-	(*driver->End_raster) ();
+        (*driver->End_raster)();
 }
