@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: safileio.c,v 1.4 2008-01-16 20:05:14 bram Exp $
+ * $Id: safileio.c,v 1.6 2018-06-15 19:56:32 erouault Exp $
  *
  * Project:  Shapelib
  * Purpose:  Default implementation of file io based on stdio.
@@ -9,11 +9,11 @@
  * Copyright (c) 2007, Frank Warmerdam
  *
  * This software is available under the following "MIT Style" license,
- * or at the option of the licensee under the LGPL (see LICENSE.LGPL).  This
+ * or at the option of the licensee under the LGPL (see COPYING).  This
  * option is discussed in more detail in shapelib.html.
  *
  * --
- * 
+ *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
  * to deal in the Software without restriction, including without limitation
@@ -34,11 +34,21 @@
  ******************************************************************************
  *
  * $Log: safileio.c,v $
+ * Revision 1.6  2018-06-15 19:56:32  erouault
+ * * safileio.c: remove duplicate test. Patch by Jaroslav Fojtik.
+ * Fixes http://bugzilla.maptools.org/show_bug.cgi?id=2744
+ *
+ * Revision 1.5  2016-12-05 12:44:05  erouault
+ * * Major overhaul of Makefile build system to use autoconf/automake.
+ *
+ * * Warning fixes in contrib/
+ *
  * Revision 1.4  2008-01-16 20:05:14  bram
- * Add file hooks that accept UTF-8 encoded filenames on some platforms.  Use SASetupUtf8Hooks
- *  tosetup the hooks and check SHPAPI_UTF8_HOOKS for its availability.  Currently, this
- *  is only available on the Windows platform that decodes the UTF-8 filenames to wide
- *  character strings and feeds them to _wfopen and _wremove.
+ * Add file hooks that accept UTF-8 encoded filenames on some platforms.  Use
+ *SASetupUtf8Hooks tosetup the hooks and check SHPAPI_UTF8_HOOKS for its
+ *availability.  Currently, this is only available on the Windows platform that
+ *decodes the UTF-8 filenames to wide character strings and feeds them to
+ *_wfopen and _wremove.
  *
  * Revision 1.3  2007/12/18 18:28:11  bram
  * - create hook for client specific atof (bugzilla ticket 1615)
@@ -46,8 +56,8 @@
  *
  * Revision 1.2  2007/12/15 20:25:30  bram
  * dbfopen.c now reads the Code Page information from the DBF file, and exports
- * this information as a string through the DBFGetCodePage function.  This is 
- * either the number from the LDID header field ("LDID/<number>") or as the 
+ * this information as a string through the DBFGetCodePage function.  This is
+ * either the number from the LDID header field ("LDID/<number>") or as the
  * content of an accompanying .CPG file.  When creating a DBF file, the code can
  * be set using DBFCreateEx.
  *
@@ -56,7 +66,7 @@
  *
  */
 
-#include <grass/shapefil.h>
+#include "shapefil.h"
 
 #include <math.h>
 #include <limits.h>
@@ -65,157 +75,150 @@
 #include <string.h>
 #include <stdio.h>
 
-SHP_CVSID("$Id: safileio.c,v 1.4 2008-01-16 20:05:14 bram Exp $")
+SHP_CVSID("$Id: safileio.c,v 1.6 2018-06-15 19:56:32 erouault Exp $")
 
 #ifdef SHPAPI_UTF8_HOOKS
-#   ifdef SHPAPI_WINDOWS
-#       define WIN32_LEAN_AND_MEAN
-#       define NOMINMAX
-#       include <windows.h>
-#       pragma comment(lib, "kernel32.lib")
-#   endif
+#ifdef SHPAPI_WINDOWS
+#define WIN32_LEAN_AND_MEAN
+#define NOMINMAX
+#include <windows.h>
+#pragma comment(lib, "kernel32.lib")
+#endif
 #endif
 
 /************************************************************************/
 /*                              SADFOpen()                              */
 /************************************************************************/
 
-SAFile SADFOpen( const char *pszFilename, const char *pszAccess )
+SAFile SADFOpen(const char *pszFilename, const char *pszAccess)
 
 {
-    return (SAFile) fopen( pszFilename, pszAccess );
+    return (SAFile)fopen(pszFilename, pszAccess);
 }
 
 /************************************************************************/
 /*                              SADFRead()                              */
 /************************************************************************/
 
-SAOffset SADFRead( void *p, SAOffset size, SAOffset nmemb, SAFile file )
+SAOffset SADFRead(void *p, SAOffset size, SAOffset nmemb, SAFile file)
 
 {
-    return (SAOffset) fread( p, (size_t) size, (size_t) nmemb, 
-                             (FILE *) file );
+    return (SAOffset)fread(p, (size_t)size, (size_t)nmemb, (FILE *)file);
 }
 
 /************************************************************************/
 /*                             SADFWrite()                              */
 /************************************************************************/
 
-SAOffset SADFWrite( void *p, SAOffset size, SAOffset nmemb, SAFile file )
+SAOffset SADFWrite(void *p, SAOffset size, SAOffset nmemb, SAFile file)
 
 {
-    return (SAOffset) fwrite( p, (size_t) size, (size_t) nmemb, 
-                              (FILE *) file );
+    return (SAOffset)fwrite(p, (size_t)size, (size_t)nmemb, (FILE *)file);
 }
 
 /************************************************************************/
 /*                              SADFSeek()                              */
 /************************************************************************/
 
-SAOffset SADFSeek( SAFile file, SAOffset offset, int whence )
+SAOffset SADFSeek(SAFile file, SAOffset offset, int whence)
 
 {
-    return (SAOffset) fseek( (FILE *) file, (long) offset, whence );
+    return (SAOffset)fseek((FILE *)file, (long)offset, whence);
 }
 
 /************************************************************************/
 /*                              SADFTell()                              */
 /************************************************************************/
 
-SAOffset SADFTell( SAFile file )
+SAOffset SADFTell(SAFile file)
 
 {
-    return (SAOffset) ftell( (FILE *) file );
+    return (SAOffset)ftell((FILE *)file);
 }
 
 /************************************************************************/
 /*                             SADFFlush()                              */
 /************************************************************************/
 
-int SADFFlush( SAFile file )
+int SADFFlush(SAFile file)
 
 {
-    return fflush( (FILE *) file );
+    return fflush((FILE *)file);
 }
 
 /************************************************************************/
 /*                             SADFClose()                              */
 /************************************************************************/
 
-int SADFClose( SAFile file )
+int SADFClose(SAFile file)
 
 {
-    return fclose( (FILE *) file );
+    return fclose((FILE *)file);
 }
 
 /************************************************************************/
 /*                             SADFClose()                              */
 /************************************************************************/
 
-int SADRemove( const char *filename )
+int SADRemove(const char *filename)
 
 {
-    return remove( filename );
+    return remove(filename);
 }
 
 /************************************************************************/
 /*                              SADError()                              */
 /************************************************************************/
 
-void SADError( const char *message )
+void SADError(const char *message)
 
 {
-    fprintf( stderr, "%s\n", message );
+    fprintf(stderr, "%s\n", message);
 }
 
 /************************************************************************/
 /*                        SASetupDefaultHooks()                         */
 /************************************************************************/
 
-void SASetupDefaultHooks( SAHooks *psHooks )
+void SASetupDefaultHooks(SAHooks *psHooks)
 
 {
-    psHooks->FOpen   = SADFOpen;
-    psHooks->FRead   = SADFRead;
-    psHooks->FWrite  = SADFWrite;
-    psHooks->FSeek   = SADFSeek;
-    psHooks->FTell   = SADFTell;
-    psHooks->FFlush  = SADFFlush;
-    psHooks->FClose  = SADFClose;
-    psHooks->Remove  = SADRemove;
+    psHooks->FOpen = SADFOpen;
+    psHooks->FRead = SADFRead;
+    psHooks->FWrite = SADFWrite;
+    psHooks->FSeek = SADFSeek;
+    psHooks->FTell = SADFTell;
+    psHooks->FFlush = SADFFlush;
+    psHooks->FClose = SADFClose;
+    psHooks->Remove = SADRemove;
 
-    psHooks->Error   = SADError;
-    psHooks->Atof    = atof;
+    psHooks->Error = SADError;
+    psHooks->Atof = atof;
 }
 
-
-
-
 #ifdef SHPAPI_WINDOWS
 
 /************************************************************************/
 /*                          Utf8ToWideChar                              */
 /************************************************************************/
 
-const wchar_t* Utf8ToWideChar( const char *pszFilename )
+const wchar_t *Utf8ToWideChar(const char *pszFilename)
 {
     int nMulti, nWide;
     wchar_t *pwszFileName;
-    
+
     nMulti = strlen(pszFilename) + 1;
-    nWide = MultiByteToWideChar( CP_UTF8, 0, pszFilename, nMulti, 0, 0);
-    if( nWide == 0 )
-    {
+    nWide = MultiByteToWideChar(CP_UTF8, 0, pszFilename, nMulti, 0, 0);
+    if (nWide == 0) {
         return NULL;
     }
-    pwszFileName = (wchar_t*) malloc(nWide * sizeof(wchar_t));
-    if ( pwszFileName == NULL )
-    {
+    pwszFileName = (wchar_t *)malloc(nWide * sizeof(wchar_t));
+    if (pwszFileName == NULL) {
         return NULL;
     }
-    if( MultiByteToWideChar( CP_UTF8, 0, pszFilename, nMulti, pwszFileName, nWide ) == 0 )
-    {
-        free( pwszFileName );
+    if (MultiByteToWideChar(CP_UTF8, 0, pszFilename, nMulti, pwszFileName,
+                            nWide) == 0) {
+        free(pwszFileName);
         return NULL;
     }
     return pwszFileName;
@@ -225,18 +228,17 @@ const wchar_t* Utf8ToWideChar( const char *pszFilename )
 /*                           SAUtf8WFOpen                               */
 /************************************************************************/
 
-SAFile SAUtf8WFOpen( const char *pszFilename, const char *pszAccess )
+SAFile SAUtf8WFOpen(const char *pszFilename, const char *pszAccess)
 {
     SAFile file = NULL;
     const wchar_t *pwszFileName, *pwszAccess;
-    pwszFileName = Utf8ToWideChar( pszFilename );
-    pwszAccess = Utf8ToWideChar( pszAccess );
-    if( pwszFileName != NULL && pwszFileName != NULL)
-    {
-        file = (SAFile) _wfopen( pwszFileName, pwszAccess );
+    pwszFileName = Utf8ToWideChar(pszFilename);
+    pwszAccess = Utf8ToWideChar(pszAccess);
+    if (pwszFileName != NULL && pwszAccess != NULL) {
+        file = (SAFile)_wfopen(pwszFileName, pwszAccess);
     }
-    free ((wchar_t*) pwszFileName);
-    free ((wchar_t*) pwszAccess);
+    free((wchar_t *)pwszFileName);
+    free((wchar_t *)pwszAccess);
     return file;
 }
 
@@ -244,15 +246,14 @@ SAFile SAUtf8WFOpen( const char *pszFilename, const char *pszAccess )
 /*                             SAUtf8WRemove()                          */
 /************************************************************************/
 
-int SAUtf8WRemove( const char *pszFilename )
+int SAUtf8WRemove(const char *pszFilename)
 {
-    const wchar_t *pwszFileName = Utf8ToWideChar( pszFilename );
-    int rc = -1; 
-    if( pwszFileName != NULL )
-    {
-        rc = _wremove( pwszFileName );
+    const wchar_t *pwszFileName = Utf8ToWideChar(pszFilename);
+    int rc = -1;
+    if (pwszFileName != NULL) {
+        rc = _wremove(pwszFileName);
     }
-    free ((wchar_t*) pwszFileName);
+    free((wchar_t *)pwszFileName);
     return rc;
 }
 
@@ -264,23 +265,23 @@ int SAUtf8WRemove( const char *pszFilename )
 /*                          SASetupUtf8Hooks()                          */
 /************************************************************************/
 
-void SASetupUtf8Hooks( SAHooks *psHooks )
+void SASetupUtf8Hooks(SAHooks *psHooks)
 {
-#ifdef SHPAPI_WINDOWS    
-    psHooks->FOpen   = SAUtf8WFOpen;
-    psHooks->Remove  = SAUtf8WRemove;
+#ifdef SHPAPI_WINDOWS
+    psHooks->FOpen = SAUtf8WFOpen;
+    psHooks->Remove = SAUtf8WRemove;
 #else
-#   error "no implementations of UTF-8 hooks available for this platform"
+#error "no implementations of UTF-8 hooks available for this platform"
 #endif
-    psHooks->FRead   = SADFRead;
-    psHooks->FWrite  = SADFWrite;
-    psHooks->FSeek   = SADFSeek;
-    psHooks->FTell   = SADFTell;
-    psHooks->FFlush  = SADFFlush;
-    psHooks->FClose  = SADFClose;
+    psHooks->FRead = SADFRead;
+    psHooks->FWrite = SADFWrite;
+    psHooks->FSeek = SADFSeek;
+    psHooks->FTell = SADFTell;
+    psHooks->FFlush = SADFFlush;
+    psHooks->FClose = SADFClose;
 
-    psHooks->Error   = SADError;
-    psHooks->Atof    = atof;
+    psHooks->Error = SADError;
+    psHooks->Atof = atof;
 }
 
 #endif
